@@ -2,7 +2,7 @@
  * 
  *  Gearmand client and server library.
  *
- *  Copyright (C) 2011-2012 Data Differential, http://datadifferential.com/
+ *  Copyright (C) 2011-2013 Data Differential, http://datadifferential.com/
  *  Copyright (C) 2008 Brian Aker, Eric Day
  *  All rights reserved.
  *
@@ -44,6 +44,7 @@
 #include "gear_config.h"
 #include "libgearman-server/common.h"
 #include <libgearman-server/gearmand.h>
+#include <libgearman-server/queue.h>
 #include <cstring>
 
 #include <cerrno>
@@ -53,6 +54,11 @@
  * Private declarations
  */
 
+void gearmand_con_st::close_socket()
+{
+  gearmand_sockfd_close(fd);
+}
+
 /**
  * @addtogroup gearmand_con_private Private Gearmand Connection Functions
  * @ingroup gearmand_con
@@ -62,35 +68,49 @@
 static gearmand_error_t _con_add(gearmand_thread_st *thread,
                                  gearmand_con_st *dcon)
 {
-  gearmand_error_t ret= GEARMAN_SUCCESS;
-  dcon->server_con= gearman_server_con_add(&(thread->server_thread), dcon, &ret);
+  gearmand_error_t ret= GEARMAND_SUCCESS;
+  dcon->server_con= gearman_server_con_add(&(thread->server_thread), dcon, ret);
 
-  assert(dcon->server_con || ret != GEARMAN_SUCCESS);
-  assert(! dcon->server_con || ret == GEARMAN_SUCCESS);
+  assert(dcon->server_con || ret != GEARMAND_SUCCESS);
+  assert(! dcon->server_con || ret == GEARMAND_SUCCESS);
 
   if (dcon->server_con == NULL)
   {
-    gearmand_sockfd_close(dcon->fd);
-
+    dcon->close_socket();
     return ret;
   }
 
-  if (dcon->add_fn)
+  if (dcon->port_st())
   {
-    ret= (*dcon->add_fn)(dcon->server_con);
+    ret= dcon->add_fn(dcon->server_con);
     if (gearmand_failed(ret))
     {
       gearman_server_con_free(dcon->server_con);
 
-      gearmand_sockfd_close(dcon->fd);
+      dcon->close_socket();
 
       return ret;
     }
   }
 
-  GEARMAN_LIST__ADD(thread->dcon, dcon);
+  GEARMAND_LIST__ADD(thread->dcon, dcon);
 
-  return GEARMAN_SUCCESS;
+  return GEARMAND_SUCCESS;
+}
+
+gearmand_error_t gearmand_con_st::add_fn(gearman_server_con_st* con_st_)
+{
+  assert(_port_st);
+  assert(con_st_);
+  assert(con_st_ == server_con);
+  return _port_st->add_fn(con_st_);
+}
+
+gearmand_error_t gearmand_con_st::remove_fn(gearman_server_con_st* con_st_)
+{
+  assert(_port_st);
+  assert(con_st_);
+  return _port_st->remove_fn(con_st_);
 }
 
 void _con_ready(int, short events, void *arg)
@@ -234,6 +254,61 @@ gearman_server_job_st *gearman_server_job_get(gearman_server_st *server,
   return NULL;
 }
 
+gearmand_error_t gearman_server_job_cancel(gearman_server_st& server,
+                                           const char *job_handle,
+                                           const size_t job_handle_length)
+{
+  gearmand_error_t ret= GEARMAND_NO_JOBS;
+  uint32_t key= _server_job_hash(job_handle, job_handle_length);
+
+  gearmand_log_debug(GEARMAN_DEFAULT_LOG_PARAM, "cancel: %.*s", int(job_handle_length), job_handle);
+
+  for (gearman_server_job_st *server_job= server.job_hash[key % server.hashtable_buckets];
+       server_job != NULL;
+       server_job= server_job->next)
+  {
+    if (server_job->job_handle_key == key and
+        strncmp(server_job->job_handle, job_handle, GEARMAND_JOB_HANDLE_SIZE) == 0)
+    {
+      /* Queue the fail packet for all clients. */
+      for (gearman_server_client_st* client= server_job->client_list; client != NULL; client= client->job_next)
+      {
+        ret= gearman_server_io_packet_add(client->con, false,
+                                          GEARMAN_MAGIC_RESPONSE,
+                                          GEARMAN_COMMAND_WORK_FAIL,
+                                          server_job->job_handle,
+                                          (size_t)strlen(server_job->job_handle),
+                                          NULL);
+        if (gearmand_failed(ret))
+        {
+          gearmand_log_gerror_warn(GEARMAN_DEFAULT_LOG_PARAM, ret, "Failed to send WORK_FAIL packet to %s:%s", client->con->host(), client->con->port());
+        }
+      }
+
+      /* Remove from persistent queue if one exists. */
+      if (server_job->job_queued)
+      {
+        ret= gearman_queue_done(Server,
+                                server_job->unique,
+                                server_job->unique_length,
+                                server_job->function->function_name,
+                                server_job->function->function_name_size);
+        if (gearmand_failed(ret))
+        {
+          return gearmand_gerror("Remove from persistent queue", ret);
+        }
+      }
+
+      server_job->ignore_job= true;
+      server_job->job_queued= false;
+
+      return GEARMAND_SUCCESS;
+    }
+  }
+
+  return ret;
+}
+
 gearman_server_job_st * gearman_server_job_peek(gearman_server_con_st *server_con)
 {
   for (gearman_server_worker_st *server_worker= server_con->worker_list;
@@ -294,7 +369,7 @@ gearman_server_job_st *gearman_server_job_take(gearman_server_con_st *server_con
 
       if (Server->flags.round_robin)
       {
-        GEARMAN_LIST_DEL(server_con->worker, server_worker, con_)
+        GEARMAND_LIST_DEL(server_con->worker, server_worker, con_)
         _server_con_worker_list_append(server_con->worker_list, server_worker);
         ++server_con->worker_count;
         if (server_con->worker_list == NULL)
@@ -345,7 +420,7 @@ gearman_server_job_st *gearman_server_job_take(gearman_server_con_st *server_con
         server_job->function->job_count--;
 
         server_job->worker= server_worker;
-        GEARMAN_LIST_ADD(server_worker->job, server_job, worker_);
+        GEARMAND_LIST_ADD(server_worker->job, server_job, worker_);
         server_job->function->job_running++;
 
         if (server_job->ignore_job)
@@ -451,7 +526,7 @@ gearman_server_job_st * gearman_server_job_create(gearman_server_st *server)
   if (server->free_job_count > 0)
   {
     server_job= server->free_job_list;
-    GEARMAN_LIST__DEL(server->free_job, server_job);
+    GEARMAND_LIST__DEL(server->free_job, server_job);
   }
   else
   {
@@ -490,16 +565,16 @@ gearman_server_job_st * gearman_server_job_create(gearman_server_st *server)
   return server_job;
 }
 
-gearmand_error_t gearmand_con_create(gearmand_st *gearmand, int fd,
+gearmand_error_t gearmand_con_create(gearmand_st *gearmand, int& fd,
                                      const char *host, const char *port,
-                                     gearmand_connection_add_fn *add_fn)
+                                     struct gearmand_port_st* port_st_)
 {
   gearmand_con_st *dcon;
 
   if (gearmand->free_dcon_count > 0)
   {
     dcon= gearmand->free_dcon_list;
-    GEARMAN_LIST__DEL(gearmand->free_dcon, dcon);
+    GEARMAND_LIST__DEL(gearmand->free_dcon, dcon);
   }
   else
   {
@@ -509,7 +584,7 @@ gearmand_error_t gearmand_con_create(gearmand_st *gearmand, int fd,
       gearmand_perror(errno, "new build_gearmand_con_st");
       gearmand_sockfd_close(fd);
 
-      return GEARMAN_MEMORY_ALLOCATION_FAILURE;
+      return GEARMAND_MEMORY_ALLOCATION_FAILURE;
     }
 
     memset(&dcon->event, 0, sizeof(struct event));
@@ -520,12 +595,11 @@ gearmand_error_t gearmand_con_create(gearmand_st *gearmand, int fd,
   dcon->next= NULL;
   dcon->prev= NULL;
   dcon->server_con= NULL;
-  dcon->add_fn= NULL;
   strncpy(dcon->host, host, NI_MAXHOST);
   dcon->host[NI_MAXHOST -1]= 0;
   strncpy(dcon->port, port, NI_MAXSERV);
   dcon->port[NI_MAXSERV -1]= 0;
-  dcon->add_fn= add_fn;
+  dcon->_port_st= port_st_;
 
   /* If we are not threaded, just add the connection now. */
   if (gearmand->threads == 0)
@@ -546,7 +620,7 @@ gearmand_error_t gearmand_con_create(gearmand_st *gearmand, int fd,
   if (dcon->thread->dcon_add_count == 0 &&
       dcon->thread->free_dcon_count < gearmand->max_thread_free_dcon_count)
   {
-    GEARMAN_LIST__ADD(dcon->thread->dcon_add, dcon);
+    GEARMAND_LIST__ADD(dcon->thread->dcon_add, dcon);
     gearmand_thread_wakeup(dcon->thread, GEARMAND_WAKEUP_CON);
   }
   else
@@ -557,7 +631,7 @@ gearmand_error_t gearmand_con_create(gearmand_st *gearmand, int fd,
     int pthread_error;
     if ((pthread_error= pthread_mutex_lock(&(dcon->thread->lock))) == 0)
     {
-      GEARMAN_LIST__ADD(dcon->thread->dcon_add, dcon);
+      GEARMAND_LIST__ADD(dcon->thread->dcon_add, dcon);
 
       /* Take the free connection structures back to reuse. */
       free_dcon_list= dcon->thread->free_dcon_list;
@@ -588,14 +662,14 @@ gearmand_error_t gearmand_con_create(gearmand_st *gearmand, int fd,
     while (free_dcon_list != NULL)
     {
       dcon= free_dcon_list;
-      GEARMAN_LIST__DEL(free_dcon, dcon);
-      GEARMAN_LIST__ADD(gearmand->free_dcon, dcon);
+      GEARMAND_LIST__DEL(free_dcon, dcon);
+      GEARMAND_LIST__ADD(gearmand->free_dcon, dcon);
     }
   }
 
   gearmand->thread_add_next= gearmand->thread_add_next->next;
 
-  return GEARMAN_SUCCESS;
+  return GEARMAND_SUCCESS;
 }
 
 void gearmand_con_free(gearmand_con_st *dcon)
@@ -610,7 +684,10 @@ void gearmand_con_free(gearmand_con_st *dcon)
     {
       /* This gets around a libevent bug when both POLLIN and POLLOUT are set. */
       event_set(&(dcon->event), dcon->fd, EV_READ, _con_ready, dcon);
-      event_base_set(dcon->thread->base, &(dcon->event));
+      if (event_base_set(dcon->thread->base, &(dcon->event)) == -1)
+      {
+        gearmand_perror(errno, "event_base_set");
+      }
 
       if (event_add(&(dcon->event), NULL) == -1)
       {
@@ -633,15 +710,15 @@ void gearmand_con_free(gearmand_con_st *dcon)
     gearman_server_con_attempt_free(dcon->server_con);
   }
 
-  GEARMAN_LIST__DEL(dcon->thread->dcon, dcon);
+  GEARMAND_LIST__DEL(dcon->thread->dcon, dcon);
 
-  gearmand_sockfd_close(dcon->fd);
+  dcon->close_socket();
 
-  if (Gearmand()->free_dcon_count < GEARMAN_MAX_FREE_SERVER_CON)
+  if (Gearmand()->free_dcon_count < GEARMAND_MAX_FREE_SERVER_CON)
   {
     if (Gearmand()->threads == 0)
     {
-      GEARMAN_LIST__ADD(Gearmand()->free_dcon, dcon);
+      GEARMAND_LIST__ADD(Gearmand()->free_dcon, dcon);
     }
     else
     {
@@ -649,7 +726,7 @@ void gearmand_con_free(gearmand_con_st *dcon)
       int error;
       if ((error=  pthread_mutex_lock(&(dcon->thread->lock))) == 0)
       {
-        GEARMAN_LIST__ADD(dcon->thread->free_dcon, dcon);
+        GEARMAND_LIST__ADD(dcon->thread->free_dcon, dcon);
         if ((error= pthread_mutex_unlock(&(dcon->thread->lock))))
         {
           gearmand_log_fatal_perror(GEARMAN_DEFAULT_LOG_PARAM, error, "pthread_mutex_unlock");
@@ -683,7 +760,7 @@ void gearmand_con_check_queue(gearmand_thread_st *thread)
     if ((error= pthread_mutex_lock(&(thread->lock))) == 0)
     {
       gearmand_con_st *dcon= thread->dcon_add_list;
-      GEARMAN_LIST__DEL(thread->dcon_add, dcon);
+      GEARMAND_LIST__DEL(thread->dcon_add, dcon);
 
       if ((error= pthread_mutex_unlock(&(thread->lock))))
       {
@@ -692,9 +769,11 @@ void gearmand_con_check_queue(gearmand_thread_st *thread)
       }
 
       gearmand_error_t rc;
-      if ((rc= _con_add(thread, dcon)) != GEARMAN_SUCCESS)
+      if ((rc= _con_add(thread, dcon)) != GEARMAND_SUCCESS)
       {
-        gearmand_gerror("_con_add() has failed, please report any crashes that occur immediatly after this.", rc);
+        gearmand_log_gerror(GEARMAN_DEFAULT_LOG_PARAM, rc, "%s:%s _con_add() has failed, please report any crashes that occur immediatly after this.",
+                            dcon->host,
+                            dcon->port);
         gearmand_con_free(dcon);
       }
     }
