@@ -39,10 +39,17 @@
 
 #pragma once
 
+struct Client;
+struct Task;
+struct Worker;
+struct gearman_client_st;
+struct gearman_connection_st;
 struct gearman_result_st;
+struct gearman_universal_st;
 
-#include <libgearman-1.0/gearman.h>
+#include "libgearman-1.0/gearman.h"
 
+#include "libgearman/server_options.hpp"
 #include "libgearman/connection.hpp"
 #include "libgearman/universal.hpp"
 #include "libgearman/allocator.hpp"
@@ -51,6 +58,7 @@ struct gearman_result_st;
 #include "libgearman/aggregator.hpp"
 
 #include "libgearman/error.hpp"
+#include "libgearman/error_code.h"
 
 /* These are private not to be installed headers */
 #include "libgearman/byteorder.h"
@@ -63,15 +71,20 @@ struct gearman_result_st;
 #include "libgearman/actions.hpp"
 #include "libgearman/string.hpp"
 #include "libgearman/command.h"
-#include "libgearman/task_attr.h"
 #include "libgearman/task.hpp"
 #include "libgearman/job.h"
+#include "libgearman/job.hpp"
 #include "libgearman/client.h"
 #include "libgearman/server_options.hpp"
+#include "libgearman/check.h"
 
 #include "libgearman/status.hpp"
 
+#include "libgearman/task_attr.h"
+
 #include "libgearman/protocol/submit.h"
+#include "libgearman/interface/client.hpp"
+#include "libgearman/interface/task.hpp"
+#include "libgearman/interface/worker.hpp"
 
-  gearman_function_t gearman_function_create_null(void);
-
+gearman_function_t gearman_function_create_null(void);
