@@ -46,13 +46,12 @@
 #include <cerrno>
 #include <cstring>
 
-void *client_do(gearman_client_st *client, gearman_command_t command,
+void *client_do(gearman_client_st *client_shell, gearman_command_t command,
                 const char *function_name,
                 const char *unique,
                 const void *workload_str, size_t workload_size,
                 size_t *result_size, gearman_return_t *ret_ptr)
 {
-  gearman_task_st do_task;
   gearman_string_t function= { gearman_string_param_cstr(function_name) };
   gearman_unique_t local_unique= gearman_unique_make(unique, unique ? strlen(unique) : 0);
   gearman_string_t workload= { static_cast<const char*>(workload_str), workload_size };
@@ -71,25 +70,27 @@ void *client_do(gearman_client_st *client, gearman_command_t command,
     ret_ptr= &unused;
   }
 
-  if (client == NULL)
+  if (client_shell == NULL or client_shell->impl() == NULL)
   {
     *ret_ptr= GEARMAN_INVALID_ARGUMENT;
     return NULL;
   }
+  Client* client= client_shell->impl();
 
-  gearman_task_st *do_task_ptr= add_task(*client, &do_task, NULL, command,
-                                         function,
-                                         local_unique,
-                                         workload,
-                                         time_t(0),
-                                         gearman_actions_do_default());
-  if (do_task_ptr == NULL)
+  gearman_task_st* do_task= add_task(*(client), NULL, NULL, command,
+                                     function,
+                                     local_unique,
+                                     workload,
+                                     time_t(0),
+                                     gearman_actions_do_default());
+
+  if (do_task == NULL)
   {
-    *ret_ptr= gearman_universal_error_code(client->universal);
+    *ret_ptr= client->universal.error_code();
     return NULL;
   }
 
-  gearman_return_t ret= gearman_client_run_block_tasks(client, do_task_ptr);
+  gearman_return_t ret= gearman_client_run_block_tasks(client, do_task);
 
   const void *returnable= NULL;
   
@@ -104,12 +105,12 @@ void *client_do(gearman_client_st *client, gearman_command_t command,
   else // Now we check the task itself
   {
     assert(ret == GEARMAN_SUCCESS); // Programmer mistake
-    if (gearman_success(do_task_ptr->result_rc))
+    if (gearman_success(do_task->impl()->error_code()))
     {
-      *ret_ptr= do_task_ptr->result_rc;
-      if (gearman_task_result(do_task_ptr))
+      *ret_ptr= do_task->impl()->error_code();
+      if (gearman_task_result(do_task))
       {
-        gearman_string_t result= gearman_result_take_string(do_task_ptr->result_ptr);
+        gearman_string_t result= gearman_result_take_string(do_task->impl()->result());
         *result_size= gearman_size(result);
         returnable= gearman_c_str(result);
       }
@@ -118,61 +119,61 @@ void *client_do(gearman_client_st *client, gearman_command_t command,
     }
     else // gearman_client_run_block_tasks() was successful, but the task was not
     {
-      gearman_error(client->universal, do_task_ptr->result_rc, "occured during gearman_client_run_tasks()");
+      gearman_error(client->universal, do_task->impl()->error_code(), "occured during gearman_client_run_tasks()");
 
-      *ret_ptr= do_task_ptr->result_rc;
+      *ret_ptr= do_task->impl()->error_code();
       *result_size= 0;
     }
   }
 
   assert(client->task_list);
-  gearman_task_free(&do_task);
+  gearman_task_free(do_task);
   client->new_tasks= 0;
   client->running_tasks= 0;
 
   return const_cast<void *>(returnable);
 }
 
-gearman_return_t client_do_background(gearman_client_st *client,
+gearman_return_t client_do_background(gearman_client_st *client_shell,
                                       gearman_command_t command,
                                       gearman_string_t &function,
                                       gearman_unique_t &unique,
                                       gearman_string_t &workload,
                                       gearman_job_handle_t job_handle)
 {
-  if (client == NULL)
+  if (client_shell == NULL or client_shell->impl() == NULL)
   {
     return GEARMAN_INVALID_ARGUMENT;
   }
+  Client* client= client_shell->impl();
 
-  gearman_task_st do_task;
-  gearman_task_st *do_task_ptr= add_task(*client, &do_task, 
-                                         client, 
-                                         command,
-                                         function,
-                                         unique,
-                                         workload,
-                                         time_t(0),
-                                         gearman_actions_do_default());
-  if (do_task_ptr == NULL)
+  gearman_task_st* do_task= add_task(*(client), NULL, 
+                                     client, 
+                                     command,
+                                     function,
+                                     unique,
+                                     workload,
+                                     time_t(0),
+                                     gearman_actions_do_default());
+  if (do_task == NULL)
   {
-    return gearman_universal_error_code(client->universal);
+    return client->universal.error_code();
   }
 
-  gearman_task_clear_fn(do_task_ptr);
+  gearman_task_clear_fn(do_task);
 
-  gearman_return_t ret= gearman_client_run_block_tasks(client, do_task_ptr);
+  gearman_return_t ret= gearman_client_run_block_tasks(client, do_task);
   assert(ret != GEARMAN_IO_WAIT);
   if (ret != GEARMAN_IO_WAIT)
   {
     if (job_handle)
     {
-      strncpy(job_handle, do_task.job_handle, GEARMAN_JOB_HANDLE_SIZE);
+      strncpy(job_handle, do_task->impl()->job_handle, GEARMAN_JOB_HANDLE_SIZE);
     }
     client->new_tasks= 0;
     client->running_tasks= 0;
   }
-  gearman_task_free(&do_task);
+  gearman_task_free(do_task);
 
   return ret;
 }
